import babel from '@babel/core';
import { esbuildPluginBabel } from './esbuildBabel.js';
const DEFAULT_FILTER = /\.jsx?$/;
const babelPlugin = ({ babelConfig = {}, filter = DEFAULT_FILTER, apply, loader } = {}) => {
    return {
        name: 'babel-plugin',
        apply,
        enforce: 'pre',
        config() {
            return {
                optimizeDeps: {
                    esbuildOptions: {
                        plugins: [
                            esbuildPluginBabel({
                                config: { ...babelConfig },
                                filter,
                                loader,
                            }),
                        ],
                    },
                },
            };
        },
        transform(code, id) {
            const shouldTransform = filter.test(id);
            if (!shouldTransform)
                return;
            return babel
                .transformAsync(code, { filename: id, ...babelConfig })
                .then((result) => ({ code: result?.code ?? '', map: result?.map }));
        },
    };
};
export default babelPlugin;
export * from './esbuildBabel.js';
//# sourceMappingURL=index.js.map